#import "SUP101CallbackHandler.h"

@implementation SUP101CallbackHandler

- (void)sendNotification:(NSNotification *)notification
{
    [[NSNotificationCenter defaultCenter] postNotification:notification];
}

- (void)postNotification:(NSString *)notification withObject:(id)obj;
{
    // All callback notifications other than onSubscribe: will happen on a thread other than the main UI thread. So, if you
    // want to update the UI in response to a callback you need to post the notification from the main thread.
    NSNotification *n = [NSNotification notificationWithName:notification object:obj];
    [self performSelectorOnMainThread:@selector(sendNotification:) withObject:n waitUntilDone:NO];
}

- (void)onConnectionStatusChange:(SUPDeviceConnectionStatus)connStatus :(SUPDeviceConnectionType)connType :(int32_t)errorCode :(NSString *)errorString
{
    NSString *notification = nil;
    switch(connStatus)
    {
        case CONNECTED_NUM:
            notification = ON_CONNECT_SUCCESS;
            break;
        case DISCONNECTED_NUM:
            notification = ON_CONNECT_FAILURE;
            break;
        default:
            // Ignore all other status changes for this example.
            break;
    }
    
    if (notification != nil) [self postNotification:notification withObject:nil];
}

- (void)onReplaySuccess:(id)theObject
{
    MBOLogInfo(@"================================================");
    MBOLogInfo(@"Replay Successful");
    MBOLogInfo(@"=================================================");
    
    [self postNotification:ON_REPLAY_SUCCESS withObject:theObject];
}

- (void)onReplayFailure:(id)theObject
{
    MBOLogInfo(@"================================================");
    MBOLogInfo(@"Replay Failure");
    MBOLogInfo(@"=================================================");
    
    [self postNotification:ON_REPLAY_FAILURE withObject:theObject];
}

- (void)onLoginSuccess
{
    MBOLogInfo(@"================================================");
    MBOLogInfo(@"Login Successful");
    MBOLogInfo(@"=================================================");
    
    [self postNotification:ON_LOGIN_SUCCESS withObject:nil];
}

- (void)onLoginFailure
{
	MBOLog(@"=============================");
	MBOLogError(@"Login Failed");
	MBOLog(@"=============================");
    
	[self postNotification:ON_LOGIN_FAILURE withObject:nil];
}

- (void)onSubscribeSuccess
{
    MBOLogInfo(@"================================================");
    MBOLogInfo(@"Subscribe Successful");
    MBOLogInfo(@"=================================================");
}

- (void)onImportSuccess
{
    MBOLogInfo(@"================================================");
    MBOLogInfo(@"import ends Successful");
    MBOLogInfo(@"=================================================");
    
    [self postNotification:ON_IMPORT_SUCCESS withObject:nil];
}

@end
